@@ -1,5 +1,5 @@
 
-as.list.its <- function(x) {
+as.list.its <- function(x,...) {
 	result <- if (ncol(x) == 1) list(x)
 	else lapply(seq(length = ncol(x)), function(i) x[,i])
 	names(result) <- colnames(x)
